@@ -4,15 +4,17 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef DEVICESPROXYMODEL_H
-#define DEVICESPROXYMODEL_H
+#pragma once
 
 #include <BluezQt/DevicesModel>
 #include <QSortFilterProxyModel>
 
+#include <qqmlregistration.h>
+
 class DevicesProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
 public:
     enum AdditionalRoles {
@@ -32,5 +34,3 @@ public:
 private:
     bool duplicateIndexAddress(const QModelIndex &idx) const;
 };
-
-#endif // DEVICESPROXYMODEL_H
